/**********************************************************************************/
/*    Demo program for:								  */
/*	  Board: MSP430-PIR     						  */
/*    Manufacture: OLIMEX                                                   	  */
/*	  COPYRIGHT (C) 2011							  */
/*    Designed by: Engineer Penko T. Bozhkov                                      */
/*    Module Name    :  main module                                               */
/*    File   Name    :  main.c                                                    */
/*    Revision       :  initial                                                   */
/*    Date           :  08.02.2011                                                */
/*    Built with IAR Embedded Workbench Version: 4.21                             */
/**********************************************************************************/
#include  <intrinsics.h>
#include  <msp430x20x3.h>

#define _BIC_SR(reg) __bic_SR_register(reg)
#define _BIS_SR(reg) __bis_SR_register(reg)

#define LED1_ON                 P1OUT |= 0x01; //P1DIR |= 0x01;
#define LED1_OFF                P1OUT &= ~0x01; //P1DIR |= 0x01;
#define LED1_Check              (P1IN & 0x01)


unsigned int Counter;

/**********************************************************************************/
/*  Function name: Delay                                                          */
/*  	Parameters                                                                */
/*          Input   :  No	                                                  */
/*          Output  :  No	                                                  */
/*	Action: Simple delay							  */
/**********************************************************************************/
void Delay(volatile unsigned int delay_counter){
	while(delay_counter){delay_counter--;}
}


/**********************************************************************************/
/*  Function name: Ports_initial_initialization                                   */
/*  	Parameters                                                                */
/*          Input   :  No	                                                  */
/*          Output  :  No	                                                  */
/*	Action: Define initial ports state and directions.			  */
/**********************************************************************************/
void Ports_initial_initialization(void)
{
   //input_data=P1IN;          //Read only register
  P1OUT = 0x00;               // The outputs are low
  P1SEL = 0x00;               // Peripheral module function: I/O function is selected.
  P1DIR = 0x01;               // 1 -> Output; 0 -> Input;  
  P1REN = 0x00;               // Pullup/pulldown resistor disabled
  P1IES = 0x00;               // Interrupt Edge Select Registers
  P1IE = 0x00;                // Disable all PORTx interrupts
  P1IFG = 0x00;               // Clear all interrupt flags

   //input_data=P2IN;          //Read only register
  P2OUT = 0x00;               // The outputs are low
  P2SEL = 0x00;               // Peripheral module function: I/O function is selected.
  P2DIR = 0x00;               // 1 -> Output; 0 -> Input
  P2REN = 0x00;               // Pullup/pulldown resistor disabled
  P2IES = 0x00;               // Interrupt Edge Select Registers
  P2IE = 0x00;                // Disable all PORTx interrupts
  P2IFG = 0x00;               // Clear all interrupt flags

}


/**********************************************************************************/
/*  Function name: init_devices	                                                  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Initialize all used MSP430F2274 peripheral devices.	  	  */
/**********************************************************************************/
void init_devices(void){
  _BIC_SR(GIE); // Disable interrupts during initialization process
  
  /********** 1.Ports initialization ***********/
  Ports_initial_initialization();
  /********** 2.Select System Clock  ***********/
  // By default System Clock is 1.1MHz DCO Clock
  
  /********** 3.Peripherals initialization ***********/
  // 3.1. Timer_A
  // =============
  TACTL = 0x0004;   // Timer_A clear.
  TACCTL0 = 0x0010; // Timer_A Capture/compare interrupt enable.
  TACCR0 = 0x007F;  // Set TACCR0 value
  TACTL = 0x02D0;   // Selected: SMCLK, Divider 1:8, Up mode.
  //TAIV = 0x000A;

  _BIS_SR(GIE); // Global Interrupt enabled. Do this at the END of the initialization!!!!!!!!
}


/**********************************************************************************/
/*  Function name: main	                                                  	  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Call "init_devices".                    	  		  */
/**********************************************************************************/
void  main(void){
  WDTCTL = 0x5A80;              // Stop WDT
  init_devices();
  while(1){
    
  }
}


/**********************************************************************************/
/*  Function name: TIMERA_Capture_Compare_ISR                                  	  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action:  Toggle LED1 and LED2 with frequency ~ 1Hz.                       */
/**********************************************************************************/
#pragma vector=TIMERA0_VECTOR
__interrupt void TIMERA_Capture_Compare_ISR(void){
  // Toggle LED
  Counter++;
  if(Counter == 1023){
    Counter = 0;
    if(LED1_Check){
      LED1_OFF;
    }
    else{
      LED1_ON;
    }
  }
}




